// General declarations and macros.
//
// Copyright (c) 2002 by Michael Newman, All rights reserved.
//
// Modification History:
//  22Apr02 MJNewman 1: Created

// this header can be included more than once. This prevents errors in
// that case
#ifndef __BASETYPE__H
#define __BASETYPE__H

#define basetypeHedit 1

/* By default BASETYPE includes some standard system libraries. Set this
** flag to 0 to prevent this.
*/
#ifndef __BASETYPE_INCLUDE_SYS
#define __BASETYPE_INCLUDE_SYS 1
#endif

#if  (__BASETYPE_INCLUDE_SYS)
#include <sys/types.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <ctype.h>
#endif

/* provide default value for UNIX of 0 */
#ifndef UNIX
#define UNIX 0
#endif

/* Try to determine if we are on the DOS platform */
#ifdef __MSDOS__
#ifndef MSDOS
#define MSDOS 1
#endif
#else
#ifndef MSDOS
#define MSDOS 0
#endif
#endif

/* on the borland platform we can force ANSI_C */
#ifdef __TURBOC__
#ifndef ANSI_C
#define ANSI_C 1
#endif
#endif

/* for Microsoft C/C++ development */
#ifdef _MSC_VER
#ifndef ANSI_C
#define ANSI_C 1
#endif
#endif

/* this is used to control some header formats for old compilers */
#ifndef ANSI_C
#ifdef __STDC__
#define ANSI_C 1
#else
#define ANSI_C 0
#endif
#endif

/* set up some environment specific items if ANSI vs non ANSI */
#if ANSI_C
#include <stdarg.h>
#else
#ifndef const
#define const
#endif
#endif

/* this marks functions as exportable in the windows environment */
#ifdef __TURBOC__
#undef EXPORT
#ifdef __STDC__
#define EXPORT
#else
#define EXPORT _export far pascal
#endif
#else
#ifndef _MSC_VER
#define EXPORT
#endif
#endif


/* Some compilers support a variety of compile time tests in #if conditionals.
** These include using the sizeof operator against structs and comparison
** against enum values. If possible this feature is used to validate
** data structure sizes and lengths. For compilers that do not support
** these tests turn of the check by defining the symbol
**COMPILE_TIME_CHECKS_SUPPORTED here.
*/
#ifdef __WATCOMC__
#define COMPILE_TIME_CHECKS_SUPPORTED 0
#endif

#ifdef _MSC_VER
#define COMPILE_TIME_CHECKS_SUPPORTED 0
#endif

#ifdef __TURBOC__
#define COMPILE_TIME_CHECKS_SUPPORTED 1
#endif

#ifndef COMPILE_TIME_CHECKS_SUPPORTED
#define COMPILE_TIME_CHECKS_SUPPORTED 1
#endif

/* EXTERNDEF is a routine that is available outside the module */
/* EXTERNVAR is a variable that is available outside the module */
/* EXTERNREF is a prototype for such a routine or variable */
/* LOCALDEF is a routine that is available only within the module */
/* LOCALVAR is a variable that is available only within the module */
/* LOCALREF is a prototype for such a routine or variable */
#define EXTERNDEF
#define EXTERNVAR
#define EXTERNREF extern
#define EXTERNC extern "C"
#define LOCALDEF static
#define LOCALVAR static
#define LOCALREF static

#ifndef TRUE
#define TRUE 1
#endif
#ifndef FALSE
#define FALSE 0
#endif

#define INT8 char		/* 8 bit integer */
#define UINT8 unsigned char	/* unsigned 8 bit integer */
#define INT16 short int		/* 16 bit integer */
#define UINT16 unsigned short int /* unsigned 16 bit integer */
#define INT32 long int		/* 32 bit integer */
#define UINT32 unsigned long int /* 32 bit integer */
#define INT int		/* system dependent integer */
#define UINT unsigned int /* system dependent integer */
#define BOOLEAN char
#define BIT_BOOLEAN unsigned int /* bitfield data type of TRUE or FALSE */ 

/* On some DG platforms pointers to void are problematic. These are treated
** as pointers to char where it matters. The VOID symbol is used to indicate
** what is really going on and to have the other platforms do the correct
** pointer to void construct. NETPHONE does not run on the problem platforms
** but some of the modules stolen from TDLINK use the VOID symbol
** to circumvent this problem.
*/
#ifndef VOID
#define VOID void
#endif

/* function taking nothing returning a void */
typedef void VOIDfVOID(void);
typedef VOIDfVOID *pFVOID;		/* pointer to above function */
typedef VOIDfVOID *pVOIDfVOID;		/* pointer to above function */

/* function taking char returning a void */
typedef void VOIDfCHAR(char);
typedef VOIDfCHAR *PVFCHAR;		/* pointer to above function */
typedef VOIDfCHAR *pVOIDfCHAR;		/* pointer to above function */

/* function taking a string returning a void */
typedef void VOIDfSTRING(char *);
typedef VOIDfSTRING *PVFSTRING;		/* pointer to above function */
typedef VOIDfSTRING *pVOIDfSTRING;	/* pointer to above function */

/* function taking int returning a BOOL */
typedef char BOOLfINT(int);
typedef BOOLfINT *pBOOLfINT;		/* pointer to above function */

/* function taking char returning a char */
typedef char CHARfCHAR(char);
typedef CHARfCHAR *pCHARfCHAR;		/* pointer to above function */

/* function taking (int,int) returing nothing */
typedef void VOIDf2INT(int,int);
typedef VOIDf2INT *pVOIDf2INT;		/* pointer to above function */

/* match modern macros if missing */
#ifndef EXIT_FAILURE
#define EXIT_FAILURE 1
#endif

/* match modern macros if missing */
#ifndef EXIT_SUCCESS
#define EXIT_SUCCESS 0
#endif

/* calculate the number of entrys in something */
#ifndef DIM
#define DIM(_x)          ((sizeof(_x)/sizeof(_x[0])))
#endif

/* figure the max or min of numbers */
#ifndef MAX
#define MAX(_a,_b) ((_a > _b) ? _a : _b)
#endif
#ifndef MIN
#define MIN(_a,_b) ((_a < _b) ? _a : _b)
#endif

/* used for lengths of strings where stack space is not of concern */
#define STRING_LENGTH 200

/* various characters */
#ifndef NUL
#define NUL ((char)'\0')    /* the null character */
#endif
#define BACKSPACE 0x08
#ifndef ESC
#define ESC 27
#endif
#define UPARROW 72
#define LEFTARROW 75
#define DOWNARROW 80
#define OPEN_PAREN '('
#define CLOSE_PAREN ')'
#define OPEN_SQUARE_BRACE '['
#define CLOSE_SQUARE_BRACE ']'

#endif	/* __BASETYPE__H */
