#  This file compiles the LOGGER program.
#
# Copyright (c) 2002 by Michael Newman All rights reserved.
#
# Modification History:
#   22Apr02 MJNewman:	Created
#
# **********************************************************************
#
# Required environment setup:
# Environment variables:
#
#	BC_VERSION	Set to the base version number of the Borland compiler.
#			Expected values are 3 and 4. Default is 3.
#
#	BCPP_DIR	Sets the Borland C base directory (default \BORLANDC)
#
#  Because some dependencies are synthetic,  only build legal targets.
#
#  Legal targets are:
#
# Batch	Target	 Primary
# File	Name	 File(s) built	Reason for this build
# ===	====	 =============	=====================
#      *LOGGER	 logger.exe	logger program
#      *HISTORY  history.txt	Extracts history from all sources.
#	CLEAN			remove generated files

DEFAULT : LOGGER

#
# C++ new options:
#   -G speed over size
#   -O now suppresses redundant register loads, still does jump optimization
#   -Z assume ptrs and direct access not mixed
# tcc options:
#   -1- Use 8086 instructions
#   -1	Use 80186 instructions
#   -A	ANSI compiler checks
#   -AK	limit compiler to Kernighan + Ritchie keywords
#   -AT	allow full Borland keywords
#   -B	contains inline assembly
#   -b  make enums word sized (REQUIRED because of cross network issues)
#   -b- make enums byte sized when possible
#   -c	compile to obj, no link
#   -dc put string literals in the code segment (Borland 4.0 and later)
#   -D	define a symbol
#   -f	generate floating point code for emulation of 8087
#   -f- suppress floating point code generation
#   -H  enable precompiled headers
#   -H=file  put them in an explicit file, (.pci is used to allow search of .c*)
#   -I	path for include files
#   -in	limit symbol names to n characters
#   -ml large memory model
#   -mm medium memory model
#   -ms small memory model
#   -N	stackcheck on function entries
#   -O	optimize loops, switchs, etc.
#   -r- disable use of register variables (DON'T use this)
#   -S	compile to asm only
#   -v	include debugger information
#   -w	enable ALL warnings

##############################################################################
#
#  *****  Environment Paths should be defined here, and NOT referenced	******
#  *****  directly in the make commands !!				******
#
##############################################################################


##############################################################################
#
# *************	 Establish base directory for Borland C++  *******************
# *************	 A second base directory is used for embedded compiles *******
#
##############################################################################

!if $d(BCPP_DIR)
#   ----- Borland top directory defined by user -----
!else
BCPP_DIR = \bc5		# normal C++ base directory
!endif

##############################################################################
#	Include file search path definitions
##############################################################################
#
#
# NOTE: the NET includes are first because FTP has some special ones that
#	must hide the Borland files.
# NOTE:	In Borland V3.1 the class libraries are in classlib\include in
#	V4.0 they are in include\classlib and referenced explicitly.
#	Similarly the OWL librarys are in owl\include and for 4.0 in
#	include\owl and referenced explicitly.
#
# Here we conditionally set up the proper paths to find included files.
# The default is set for Borland 3.1. To get 4.0 style define BC_VERSION to 4.
# To avoid command line length problems the path is split into two
# portions; C_INCLUDE and CLASS_INCLUDE. The C_INCLUDE portion is embedded in
# the configuration files cswtich.cfg and wswitch.cfg. The CLASS_INCLUDE
# portion is used directly on the command line because it varies
# depending on compiler version. Thus the cswitch.cfg and wswitch.cfg files
# do not need to be rebuilt when the compiler version changes.
#
!if ($d(BC_VERSION) && ($(BC_VERSION)>=4))
CLASS_INCLUDE = $(BCPP_DIR)\include\classlib
!if ($(BC_VERSION)>=5)
COMPILER_FLAG = BCPP50
!else
COMPILER_FLAG = BCPP45
!endif
!else
CLASS_INCLUDE = $(BCPP_DIR)\classlib\include;$(BCPP_DIR)\owl\include
COMPILER_FLAG = BCPP31
!endif
C_INCLUDE = $(BCPP_DIR)\include;tn\inc;nci
C_LIBRARY = $(BCPP_DIR)\lib
WC_INCLUDE = $(C_INCLUDE)
WC_LIBRARY = $(BCPP_DIR)\lib

### Compile and link commands
# 32-bit tools for T1/486 architecture
CC32 = $(BCPP_DIR)\bin\bcc32 +wswitch.cfg
TLINK32 = $(BCPP_DIR)\bin\tlink32 -v -M -ap -OS

# Windows style compilation
wswitch.cfg : logger.mak
  copy &&|
-b		# use 32 bit enums
-C		# Case sensitive exports
-c-		# compile and link
-d		# Merge duplicate strings
-ff-		# strict ANSI float (why, I don't know)
-G		# speed over size
-H=wswitch.pci	# put them in this file
-H-		# disable precompiled headers
-I$(C_INCLUDE)	# Basic C inclusions
-O		# optimize
-R		# include browser information in objects
-v		# debugging info pleze
-vi		# expand inline functions
-w		# all warnings
-X-		# compiler autodependency output enabled
-Z		# assume ptrs and direct access not mixed
| wswitch.cfg

#-D_OWLDLL	# borland OWL will be used as a DLL
#-D_BIDSDLL	# borland class library will be used as a DLL
#-D_RTLDLL	# borland run time library will be used as a DLL
# -a		# ** word alignment ** required for windows/CV, UNLIKE B100
# -Ff		# kick large objects out into private data segments
# -Ff=xxx	# set kick-out threshold above (default is 32767 !)
# -N		# stack checking on function entries
#		# ???stack checking interfears with target platform
#		#    control-break
# -k-		# non-standard stack frame
# -R		# Generate ObjectBrowser info
# -Vo		# specifies compatability with C++ v2.0 libs required...
# -Vf		# far virtual tables
# -WS		# Smart callbacks for Windows
# -WE		# explicit export functions for Windows




##############################################################################
#	Primary compilation
##############################################################################

LOGGER : wswitch.cfg logger.exe

logger.exe : logger.c basetype.h ping.h ping.c
	$(CC32) logger.c ping.c

CLEAN :
	-1 del *.obj
	-1 del wswitch.cfg
	-1 del logger.zip
	-1 del *.exe

logger.zip : LOGGER
	zip -x*.log logger.zip logger.exe *.c *.h *.mak	*.bat

RELEASE : LOGGER logger.zip
	copy logger.exe \\server\g\dragonnorth\htmltricks\logger.exe
	copy logger.zip \\server\g\dragonnorth\htmltricks\logger.zip